/******************************************************************************		
*                                                                                   	
*       Copyright (C) 2006 Freescale Semiconductor, Inc.                            	
*       All Rights Reserved								              				
*														              					
* Filename:      bout.h               											
* 
* Author:        Christine Peng
*
* Release:       August 15, 2006            											
*														             													              					
* Description:	 Brownout System Protection Software for MC9S08DZ60.
*                This software utilizes the on-chip system protection
*                features of the MC9S08DZ60 for brownout protection. 	        	    	
*                Developed with CodeWarrior 5.0                       						
*																						
* Notes:         
*                COP Reset event -  PTD0 = 0  (LED ON)
*                ILOP Reset event - PTD1 = 0  (LED ON)
*                ILAD Reset event - PTD3 = 0  (LED ON)
*                MCG external clock loss of clock event - RESET MCU - PTD4 = 0 (LED ON)  
*                LVD event - RESET MCU - PTD5 = 0 (LED ON)
*                LVW event - PTD6 = 0 (LED ON)-> 1 (OFF) if Vdd rises above 4.7 V again
*                MCG external clock loss of lock event - PTD7 = 0 (LED ON)
*
*                To test MCG LOL and LOC, a 4 MHz crystal is required with
*                this software, and "#define EXTXTAL" in "bout.h" must be
*                uncommented. Otherwise, LOL and LOC will never occur because
*                the MCG will use the internal oscillator.   
* 																		
*  ***********************************************************************  			
*  *  THIS CODE IS ONLY INTENDED AS AN EXAMPLE OF CODE FOR THE           *  	 		
*  *  CODEWARRIOR COMPILER AND HAS ONLY BEEN GIVEN A MIMIMUM             *  	 		
*  *  LEVEL OF TEST. IT IS PROVIDED 'AS SEEN' WITH NO GUARANTEES         *  	 		
*  *  AND NO PROMISE OF SUPPORT.                                         *  	 		
*  ***********************************************************************  	 		
*																						
* Freescale reserves the right to make changes without further notice to any			
* product herein to improve reliability, function, or design. Freescale does	 		
* not assume any  liability arising  out  of the  application or use of any 	 		
* product,  circuit, or software described herein;  neither  does it convey 	 		
* any license under its patent rights  nor the  rights of others.  Freescale	 		
* products are not designed, intended,  or authorized for use as components 	 		
* in  systems  intended  for  surgical  implant  into  the  body, or  other 	 		
* applications intended to support life, or  for any  other application  in 	 		
* which the failure of the Freescale product  could create a situation where	 		
* personal injury or death may occur. Should Buyer purchase or use Freescale	 		
* products for any such intended  or unauthorized  application, Buyer shall 	 		
* indemnify and  hold  Freescale  and its officers, employees, subsidiaries,	 		
* affiliates,  and distributors harmless against all claims costs, damages, 	  		
* and expenses, and reasonable  attorney  fees arising  out of, directly or 	 		
* indirectly,  any claim of personal injury  or death  associated with such 	 		
* unintended or unauthorized use, even if such claim alleges that  Freescale	 		
* was negligent regarding the  design  or manufacture of the part. Freescale	 		
* and the Freescale logo* are registered trademarks of Freescale Ltd.       	 		
******************************************************************************/		



#ifndef BOUT_H               /* Prevent duplicated includes */
#define BOUT_H

/* DEFINES */    
#define BGVAL 0x0105         /* 0x105 corresponds to Vbg when Vdd at 4.7 V - used for ADC    */ 
                             /* BGVAL = h(1024 * 1.2/4.7)  */   
/* VARIABLE */
static byte ExtClkFlg = 0;                             


/* FUNCTION PROTOTYPES */
void PortsInit (void);
void PWMInit (void);
void MCGInit (void);
void TestOptions (void);
void ResetErrorHandler (void);

#endif                       /* BOUT_H */